@@ -97,7 +97,6 @@ class AsyncStorage:
         splitter = AsyncSplitWriter(writer, query_id=str(query_id))
         await splitter.init()
 
-        #async for obj in _transform(bundle):
         for obj in _transform(bundle):
             await splitter.write(obj)
         await splitter.close()
@@ -148,14 +147,20 @@ class AsyncStorage:
         rows = await self.conn.fetch(stmt, self.session_id, viewname)
         return [i['column_name'] for i in rows]
 
-    async def schema(self, viewname):
+    async def schema(self, viewname=None):
         """Get the schema (names and types) of `viewname`"""
-        validate_name(viewname)
-        stmt = ("SELECT column_name AS name, data_type AS type"
-                " FROM information_schema.columns"
-                " WHERE table_schema = $1"
-                " AND table_name = $2")
-        rows = await self.conn.fetch(stmt, self.session_id, viewname)
+        if viewname:
+            validate_name(viewname)
+            stmt = ("SELECT column_name AS name, data_type AS type"
+                    " FROM information_schema.columns"
+                    " WHERE table_schema = $1"
+                    " AND table_name = $2")
+            rows = await self.conn.fetch(stmt, self.session_id, viewname)
+        else:
+            stmt = ("SELECT table_name AS name, column_name AS name, data_type AS type"
+                    " FROM information_schema.columns"
+                    " WHERE table_schema = $1")
+            rows = await self.conn.fetch(stmt, self.session_id)
         return [dict(row) for row in rows]
 
     async def delete(self):
@@ -193,9 +198,9 @@ class AsyncStorage:
         return [dict(row) for row in rows]
 
     async def run_query(self, query: Query):
-        query_text, query_values = query.render(self.Placeholder(), self.dialect)
-        result = await self.conn.fetch(query_text, *query_values)
-        return result
+        query_text, query_values = query.render(self.placeholder, self.dialect)
+        result = await self.fetch(query_text, *query_values)
+        return [dict(r) for r in result]
 
     async def fetch(self, query, *args):
         """Passthrough to underlying DB"""
@@ -401,9 +406,12 @@ class AsyncSplitWriter:
         return OrderedDict({col['name']: col['type'] for col in props})
 
     async def _load_schemas(self):
-        types = await self.writer.types(True)
-        for obj_type in types:
-            self.schemas[obj_type] = await self._load_schema(obj_type)
+        cols = await self.writer.properies()
+        for col in cols:
+            schema = self.schemas.get(col['table'], {})
+            schema[col['name']] = col['type']
+            self.schemas[col['table']] = schema
+        # TODO: is this necessary?
         self.schemas['__columns'] = OrderedDict({
             'otype': 'TEXT',
             'path': 'TEXT',
@@ -413,10 +421,7 @@ class AsyncSplitWriter:
 
     async def write(self, obj):
         """Consume `obj` (actual writing to storage may be deferred)"""
-        #TODO: do less work on obj in here; wait until we hit batchsize?
-        #   just collect objs, then create DataFrame
-        #   Compare df.columns to schema and then try new_prop/type
-        obj.update(self.extras)
+        obj.update(self.extras)  # unused?
         obj_type = obj['type']
         schema = self.schemas.get(obj_type)
         add_table = False
@@ -430,13 +435,16 @@ class AsyncSplitWriter:
                 # Found new table
                 schema = OrderedDict()
                 add_table = True
-            if obj_type == '__contains' and 'x_firepit_rank' not in obj:
-                obj['x_firepit_rank'] = 0   # TEMP: HACK.
+            #if obj_type == '__contains' and 'x_firepit_rank' not in obj:
+            #    obj['x_firepit_rank'] = 1   # TEMP: HACK.
             for key, value in obj.items():
                 if key in ['type', 'spec_version']:
                     continue
                 # shorten key (STIX prop) to make column names more manageable
-                shortname = self.writer.shorten(key)  # Need to detect collisions!
+                if len(key) > 63 or 'extensions.' in key:
+                    shortname = self.writer.shorten(key)  # Need to detect collisions!
+                else:
+                    shortname = key
                 new_obj[shortname] = value
                 if shortname not in schema:
                     # Found new column
@@ -504,6 +512,7 @@ class AsyncSplitWriter:
                     raise e
 
 
+
 # adapted from SqlStorage
 def _get_excluded(colnames, tablename):
     text_min = 'LEAST'
@@ -593,8 +602,10 @@ class AsyncSqlWriter:
 
         # Load records into dataframe and do type conversions as required
         df = pd.DataFrame(records)
-        for col in df.columns:
+        columns = df.columns
+        for col in columns:
             if col not in schema:
+                #df = df.drop(columns=col)
                 continue
             stype = schema[col].lower()
             if stype == 'text':
@@ -603,6 +614,8 @@ class AsyncSqlWriter:
                 df[col] = df[col].astype('Int64')
             elif stype == 'integer':
                 df[col] = df[col].astype('Int32')
+            elif stype == 'boolean':
+                df[col] = df[col].astype('boolean')
 
         #TODO: if no id column, use drop_duplicates?
 
@@ -610,10 +623,9 @@ class AsyncSqlWriter:
         if 'type' in df.columns:
             df = df.drop(columns='type')
 
-        colnames = list(df.columns)
+        colnames = list(df.columns)  #schema.keys())
         quoted_colnames = [f'"{x}"' for x in colnames]
         valnames = ', '.join(quoted_colnames)
-        logger.debug('valnames (%d): %s', len(quoted_colnames), valnames)
 
         # Replace NaNs with None, since asyncpg won't do it
         # Then convert back to "record" format
@@ -671,6 +683,21 @@ class AsyncSqlWriter:
             qobjs = [(obj[idx], query_id) for obj in records]
             await self.conn.copy_records_to_table('__queries', records=qobjs)
 
+    async def types(self, private=False):
+        #tables = self.store.types(private)
+        #return [_strip_prefix(table, self.prefix) for table in tables]
+        stmt = ("SELECT table_name FROM information_schema.tables"
+                " WHERE table_schema = $1 AND table_type != 'VIEW'"
+                "  EXCEPT SELECT name as table_name FROM __symtable")
+        rows = await self.conn.fetch(stmt, self.session_id)
+        if private:
+            tables = [i['table_name'] for i in rows]
+        else:
+            # Ignore names that start with 1 or 2 underscores
+            tables = [i['table_name'] for i in rows
+                      if not i['table_name'].startswith('_')]
+        return tables
+
     async def properties(self, obj_type):
         tablename = f'{self.prefix}{obj_type}'
         stmt = ("SELECT column_name AS name, data_type AS type"
@@ -683,10 +710,10 @@ class AsyncSqlWriter:
 
 class AsyncRecordList(RecordList):
     def __init__(self):
-        super().__init__(None)
+        super().__init__(1)
 
     def append(self, record):
-        rec_id = record['id']
+        rec_id = record.get('id', len(self.records))
         if rec_id in self.records:
             # Update record instead
             self.records[rec_id].update(record)
@@ -760,7 +787,7 @@ class AsyncDBCache:
             cols = await self.store.columns(table)
             self.col_dict[table] = cols
         else:
-            logger.info('DBCache: fetching columns for "%s" from cache', table)
+            logger.debug('DBCache: fetching columns for "%s" from cache', table)
             cols = self.col_dict[table]
         return cols
 
