@@ -6,6 +6,7 @@ from collections import OrderedDict, defaultdict
 import ujson
 
 from firepit.exceptions import DuplicateTable
+from firepit.exceptions import InvalidObject
 
 
 logger = logging.getLogger(__name__)
@@ -152,8 +153,8 @@ class SqlWriter:
         tables = self.store.types(private)
         return [_strip_prefix(table, self.prefix) for table in tables]
 
-    def properties(self, obj_type):
-        tablename = f'{self.prefix}{obj_type}'
+    def properties(self, obj_type=None):
+        tablename = f'{self.prefix}{obj_type}' if obj_type else None
         return self.store.schema(tablename)
 
 
@@ -211,16 +212,21 @@ class SplitWriter:
         pass
 
     def _load_schema(self, obj_type):
+        logger.debug('_load_schema for %s', obj_type)
         return {col['name']: col['type'] for col in self.writer.properties(obj_type)}
 
     def _load_schemas(self):
-        for obj_type in self.writer.types(True):
-            self.schemas[obj_type] = self._load_schema(obj_type)
+        for col in self.writer.properties():
+            schema = self.schemas.get(col['table'], {})
+            schema[col['name']] = col['type']
+            self.schemas[col['table']] = schema
 
     def write(self, obj):
         """Consume `obj` (actual writing to storage may be deferred)"""
         obj.update(self.extras)
         obj_type = obj['type']
+        if not obj_type:
+            raise InvalidObject('empty `type` property')
         schema = self.schemas.get(obj_type)
         add_table = False
         add_col = False
@@ -234,7 +240,10 @@ class SplitWriter:
             if key in ['type', 'spec_version']:
                 continue
             # shorten key (STIX prop) to make column names more manageable
-            shortname = self.writer.shorten(key)  # Need to detect collisions!
+            if len(key) > 63 or 'extensions.' in key:
+                shortname = self.writer.shorten(key)  # Need to detect collisions!
+            else:
+                shortname = key
             new_obj[shortname] = value
             if shortname not in schema:
                 # Found new column
