@@ -50,7 +50,7 @@ def _transform(filename):
     for obj in raft.get_objects(filename):  #, ['identity', 'observed-data']):
         # Some identity objects from stix-shifter are missing a `type` property?
         if 'type' not in obj:
-            obj['type'], _, _ = obj['id'].partition('--')
+            obj['type'], _, _ = obj['id'].rpartition('--')
         if obj['type'] != 'identity':
             for o in (raft.json_normalize(obj, flat_lists=False)
                       for obj in raft.flatten(obj)):
@@ -711,8 +711,11 @@ class SqlStorage:
         # This is DB-specific
         raise NotImplementedError('Storage.columns')
 
-    def schema(self, viewname):
-        """Get the schema (names and types) of `viewname`"""
+    def schema(self, viewname=None):
+        """
+        Get the schema (names and types) of table/view `viewname` or all
+        tables if not specified
+        """
         # This is DB-specific
         raise NotImplementedError('Storage.schema')
 
